texinfo-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

branch master updated: Prepend internal_ to internal text containers nam


From: Patrice Dumas
Subject: branch master updated: Prepend internal_ to internal text containers names used only for parsing
Date: Sun, 11 Sep 2022 06:01:08 -0400

This is an automated email from the git hooks/post-receive script.

pertusus pushed a commit to branch master
in repository texinfo.

The following commit(s) were added to refs/heads/master by this push:
     new 2f65b92936 Prepend internal_ to internal text containers names used 
only for parsing
2f65b92936 is described below

commit 2f65b929363bd6b2a8a544527d91a60da11ee0eb
Author: Patrice Dumas <pertusus@free.fr>
AuthorDate: Sun Sep 11 12:00:58 2022 +0200

    Prepend internal_ to internal text containers names used only for parsing
    
    * tp/Texinfo/ParserNonXS.pm, tp/Texinfo/XS/misc.c,
    tp/Texinfo/XS/parsetexi/close.c,
    tp/Texinfo/XS/parsetexi/element_types.txt,
    tp/Texinfo/XS/parsetexi/indices.c, tp/Texinfo/XS/parsetexi/menus.c,
    tp/Texinfo/XS/parsetexi/parser.c, tp/Texinfo/XS/parsetexi/separator.c:
    prepend internal_ to type names of text containers used in the parsing
    only that do not show up in the tree.  Rename empty_spaces_before_argument
    as internal_spaces_before_argument.
---
 ChangeLog                                 | 13 +++++++++++
 tp/Texinfo/ParserNonXS.pm                 | 38 +++++++++++++++----------------
 tp/Texinfo/XS/misc.c                      | 12 +++++-----
 tp/Texinfo/XS/parsetexi/close.c           |  2 +-
 tp/Texinfo/XS/parsetexi/element_types.c   |  8 +++----
 tp/Texinfo/XS/parsetexi/element_types.h   |  8 +++----
 tp/Texinfo/XS/parsetexi/element_types.txt |  8 +++----
 tp/Texinfo/XS/parsetexi/end_line.c        |  2 +-
 tp/Texinfo/XS/parsetexi/indices.c         |  2 +-
 tp/Texinfo/XS/parsetexi/menus.c           |  8 +++----
 tp/Texinfo/XS/parsetexi/parser.c          | 30 ++++++++++++------------
 tp/Texinfo/XS/parsetexi/separator.c       | 10 ++++----
 12 files changed, 77 insertions(+), 64 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index 1cc624e687..91726b8d2e 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,16 @@
+2022-09-11  Patrice Dumas  <pertusus@free.fr>
+
+       Prepend internal_ to internal text containers names used only for 
parsing
+
+       * tp/Texinfo/ParserNonXS.pm, tp/Texinfo/XS/misc.c,
+       tp/Texinfo/XS/parsetexi/close.c,
+       tp/Texinfo/XS/parsetexi/element_types.txt,
+       tp/Texinfo/XS/parsetexi/indices.c, tp/Texinfo/XS/parsetexi/menus.c,
+       tp/Texinfo/XS/parsetexi/parser.c, tp/Texinfo/XS/parsetexi/separator.c:
+       prepend internal_ to type names of text containers used in the parsing
+       only that do not show up in the tree.  Rename 
empty_spaces_before_argument
+       as internal_spaces_before_argument.
+
 2022-09-11  Patrice Dumas  <pertusus@free.fr>
 
        * tp/Texinfo/ParserNonXS.pm(_check_empty_expansion),
diff --git a/tp/Texinfo/XS/misc.c b/tp/Texinfo/XS/misc.c
index 6a9971629e..4a38efbcbc 100644
--- a/tp/Texinfo/XS/misc.c
+++ b/tp/Texinfo/XS/misc.c
@@ -97,8 +97,8 @@ xs_abort_empty_line (HV *self, HV *current, SV 
*additional_spaces_in)
   /* Must be one of these types to continue. */
   if (strcmp (type, "empty_line")
        && strcmp (type, "empty_line_after_command")
-       && strcmp (type, "internal_empty_line_after_command")
-       && strcmp (type, "empty_spaces_before_argument")
+       && strcmp (type, "internal_spaces_after_command")
+       && strcmp (type, "internal_spaces_before_argument")
        && strcmp (type, "empty_spaces_after_close_brace"))
     {
       return 0;
@@ -175,8 +175,8 @@ delete_type:
           hv_delete (spaces_elt, "type", strlen ("type"), G_DISCARD);
         }
     }
-  else if (!strcmp (type, "internal_empty_line_after_command")
-           || !strcmp (type, "empty_spaces_before_argument"))
+  else if (!strcmp (type, "internal_spaces_after_command")
+           || !strcmp (type, "internal_spaces_before_argument"))
     {
       STRLEN len;
       HV *owning_elt = 0;
@@ -279,8 +279,8 @@ xs_merge_text (HV *self, HV *current, SV *text_in)
                 type = SvPV_nolen (*svp);
               if (type
                   && (!strcmp (type, "empty_line_after_command")
-                      || !strcmp (type, "internal_empty_line_after_command")
-                      || !strcmp (type, "empty_spaces_before_argument")
+                      || !strcmp (type, "internal_spaces_after_command")
+                      || !strcmp (type, "internal_spaces_before_argument")
                       || !strcmp (type, "empty_spaces_after_close_brace")))
                 {
                   no_merge_with_following_text = 1;
diff --git a/tp/Texinfo/XS/parsetexi/close.c b/tp/Texinfo/XS/parsetexi/close.c
index ebe450d43e..f7cf63e3a8 100644
--- a/tp/Texinfo/XS/parsetexi/close.c
+++ b/tp/Texinfo/XS/parsetexi/close.c
@@ -310,7 +310,7 @@ close_current (ELEMENT *current,
           command_error (current, "misplaced {");
           if (current->contents.number > 0
               && current->contents.list[0]->type
-                 == ET_empty_spaces_before_argument)
+                 == ET_internal_spaces_before_argument)
             {
               /* remove spaces element from tree and update extra values */
               abort_empty_line (&current, 0);
diff --git a/tp/Texinfo/XS/parsetexi/element_types.c 
b/tp/Texinfo/XS/parsetexi/element_types.c
index 6f3eb4647d..32cf7c9800 100644
--- a/tp/Texinfo/XS/parsetexi/element_types.c
+++ b/tp/Texinfo/XS/parsetexi/element_types.c
@@ -10,8 +10,6 @@ char *element_type_names[] = {
 "raw",
 "empty_line_after_command",
 "spaces_at_end",
-"spaces_before_brace_in_index",
-"empty_spaces_before_argument",
 "empty_spaces_after_close_brace",
 "empty_spaces_before_paragraph",
 "text_before_beginning",
@@ -39,8 +37,10 @@ char *element_type_names[] = {
 "menu_entry_node",
 "menu_entry_description",
 "menu_comment",
-"menu_star",
-"internal_empty_line_after_command",
+"internal_menu_star",
+"internal_spaces_after_command",
+"internal_spaces_before_argument",
+"internal_spaces_before_brace_in_index",
 "macro_name",
 "macro_arg",
 "before_item",
diff --git a/tp/Texinfo/XS/parsetexi/element_types.h 
b/tp/Texinfo/XS/parsetexi/element_types.h
index d40f1a1bca..85d68799ea 100644
--- a/tp/Texinfo/XS/parsetexi/element_types.h
+++ b/tp/Texinfo/XS/parsetexi/element_types.h
@@ -13,8 +13,6 @@ ET_empty_line,
 ET_raw,
 ET_empty_line_after_command,
 ET_spaces_at_end,
-ET_spaces_before_brace_in_index,
-ET_empty_spaces_before_argument,
 ET_empty_spaces_after_close_brace,
 ET_empty_spaces_before_paragraph,
 ET_text_before_beginning,
@@ -42,8 +40,10 @@ ET_menu_entry_separator,
 ET_menu_entry_node,
 ET_menu_entry_description,
 ET_menu_comment,
-ET_menu_star,
-ET_internal_empty_line_after_command,
+ET_internal_menu_star,
+ET_internal_spaces_after_command,
+ET_internal_spaces_before_argument,
+ET_internal_spaces_before_brace_in_index,
 ET_macro_name,
 ET_macro_arg,
 ET_before_item,
diff --git a/tp/Texinfo/XS/parsetexi/element_types.txt 
b/tp/Texinfo/XS/parsetexi/element_types.txt
index 39423fb034..8f250600e0 100644
--- a/tp/Texinfo/XS/parsetexi/element_types.txt
+++ b/tp/Texinfo/XS/parsetexi/element_types.txt
@@ -28,8 +28,6 @@ empty_line
 raw
 empty_line_after_command
 spaces_at_end
-spaces_before_brace_in_index
-empty_spaces_before_argument
 empty_spaces_after_close_brace
 empty_spaces_before_paragraph
 text_before_beginning
@@ -61,8 +59,10 @@ menu_entry_node
 menu_entry_description
 menu_comment
 # Used internally
-menu_star
-internal_empty_line_after_command
+internal_menu_star
+internal_spaces_after_command
+internal_spaces_before_argument
+internal_spaces_before_brace_in_index
 
 macro_name
 macro_arg
diff --git a/tp/Texinfo/XS/parsetexi/end_line.c 
b/tp/Texinfo/XS/parsetexi/end_line.c
index 0ea014444b..827120f2ea 100644
--- a/tp/Texinfo/XS/parsetexi/end_line.c
+++ b/tp/Texinfo/XS/parsetexi/end_line.c
@@ -1767,7 +1767,7 @@ end_line_misc_line (ELEMENT *current)
               current->type = ET_index_entry_command;
             }
           /* if there is a brace command interrupting an index or subentry
-             command, replace the internal spaces_before_brace_in_index
+             command, replace the internal 
internal_spaces_before_brace_in_index
              text type with its final type depending on whether there is
              text after the brace command. */
           if ((command_flags(current) & CF_index_entry_command
diff --git a/tp/Texinfo/XS/parsetexi/indices.c 
b/tp/Texinfo/XS/parsetexi/indices.c
index df43803ddf..4a19e19cb0 100644
--- a/tp/Texinfo/XS/parsetexi/indices.c
+++ b/tp/Texinfo/XS/parsetexi/indices.c
@@ -339,7 +339,7 @@ set_non_ignored_space_in_index_before_command (ELEMENT 
*content)
       /* could also be, but it does not seems to be needed here:
          e = contents_child_by_index (content, i); */
       e = content->contents.list[i];
-      if (e->type == ET_spaces_before_brace_in_index)
+      if (e->type == ET_internal_spaces_before_brace_in_index)
         {
           pending_spaces_element = e;
           /* set to "spaces_at_end" in case there are only spaces after */
diff --git a/tp/Texinfo/XS/parsetexi/parser.c b/tp/Texinfo/XS/parsetexi/parser.c
index fccb2d5f42..a26a01bcc6 100644
--- a/tp/Texinfo/XS/parsetexi/parser.c
+++ b/tp/Texinfo/XS/parsetexi/parser.c
@@ -392,7 +392,7 @@ parse_texi_document (void)
       if (!line)
         break;
 
-      linep = line; 
+      linep = line;
       linep += strspn (linep, whitespace_chars);
       if (*linep && !looking_at (linep, "\\input"))
         {
@@ -541,8 +541,8 @@ merge_text (ELEMENT *current, char *text)
 
       if (last_child
           && (last_child->type == ET_empty_line_after_command
-              || last_child->type == ET_internal_empty_line_after_command
-              || last_child->type == ET_empty_spaces_before_argument
+              || last_child->type == ET_internal_spaces_after_command
+              || last_child->type == ET_internal_spaces_before_argument
               || last_child->type == ET_empty_spaces_after_close_brace))
         {
           no_merge_with_following_text = 1;
@@ -569,15 +569,15 @@ merge_text (ELEMENT *current, char *text)
   if (last_child
       /* There is a difference between the text being defined and empty,
          and not defined at all.  The latter is true for 'brace_command_arg'
-         elements.  We need either to make sure that we initialize all 
elements 
+         elements.  We need either to make sure that we initialize all elements
          with text_append (&e->text, "") where we want merging with following
          text, or treat as a special case here.
-         Unfortunately we can't make a special case for 
-         ET_empty_spaces_before_argument, because abort_empty_line above 
+         Unfortunately we can't make a special case for
+         ET_internal_spaces_before_argument, because abort_empty_line above
          produces such an element that shouldn't be merged with. */
       && (last_child->text.space > 0
             && !strchr (last_child->text.text, '\n')
-             ) /* || last_child->type == ET_empty_spaces_before_argument) */
+             ) /* || last_child->type == ET_internal_spaces_before_argument) */
       && last_child->cmd != CM_value
       && !no_merge_with_following_text)
     {
@@ -612,8 +612,8 @@ abort_empty_line (ELEMENT **current_inout, char 
*additional_spaces)
   if (last_child
       && (last_child->type == ET_empty_line
           || last_child->type == ET_empty_line_after_command
-          || last_child->type == ET_internal_empty_line_after_command
-          || last_child->type == ET_empty_spaces_before_argument
+          || last_child->type == ET_internal_spaces_after_command
+          || last_child->type == ET_internal_spaces_before_argument
           || last_child->type == ET_empty_spaces_after_close_brace))
     {
       retval = 1;
@@ -636,8 +636,8 @@ abort_empty_line (ELEMENT **current_inout, char 
*additional_spaces)
           last_child->type = begin_paragraph_p (current)
                              ? ET_empty_spaces_before_paragraph : ET_NONE;
         }
-      else if (last_child->type == ET_internal_empty_line_after_command
-               || last_child->type == ET_empty_spaces_before_argument)
+      else if (last_child->type == ET_internal_spaces_after_command
+               || last_child->type == ET_internal_spaces_before_argument)
         {
           /* Remove element from main tree. It will still be referenced in
              the 'extra' hash as 'spaces_before_argument'. */
@@ -782,7 +782,7 @@ isolate_last_space (ELEMENT *current)
 
 /* Add an "ET_empty_line_after_command" element containing the whitespace at 
    the beginning of the rest of the line after skipspaces commands,
-   if COMMAND is 0.  Otherwise add an "ET_internal_empty_line_after_command",
+   if COMMAND is 0.  Otherwise add an "ET_internal_spaces_after_command",
    container, after line commands or commands starting
    a block, that will end up in COMMAND extra spaces value. */
 void
@@ -802,7 +802,7 @@ start_empty_line_after_command (ELEMENT *current, char 
**line_inout,
   if (command)
     {
       add_extra_element (e, "spaces_associated_command", command);
-      e->type = ET_internal_empty_line_after_command;
+      e->type = ET_internal_spaces_after_command;
     }
 
   *line_inout = line;
@@ -1850,7 +1850,7 @@ value_invalid:
               "spaces_at_end" if followed by spaces only when the
               index or subentry command is done. */
             {
-              isolate_trailing_space (current, 
ET_spaces_before_brace_in_index);
+              isolate_trailing_space (current, 
ET_internal_spaces_before_brace_in_index);
             }
         }
 
@@ -2087,7 +2087,7 @@ parse_texi (ELEMENT *root_elt, ELEMENT *current_elt)
 
           if (current->contents.number > 0
               && last_contents_child(current)->type
-                 == ET_empty_spaces_before_argument)
+                 == ET_internal_spaces_before_argument)
             {
               /* Remove this element and update 'extra' values. */
               abort_empty_line (&current, 0);
diff --git a/tp/Texinfo/XS/parsetexi/separator.c 
b/tp/Texinfo/XS/parsetexi/separator.c
index e367d0168f..6d611eda13 100644
--- a/tp/Texinfo/XS/parsetexi/separator.c
+++ b/tp/Texinfo/XS/parsetexi/separator.c
@@ -124,7 +124,7 @@ handle_open_brace (ELEMENT *current, char **line_inout)
             ELEMENT *e;
             int n;
             n = strspn (line, whitespace_chars_except_newline);
-            e = new_element (ET_empty_spaces_before_argument);
+            e = new_element (ET_internal_spaces_before_argument);
             text_append_n (&e->text, line, n);
             add_to_element_contents (current, e);
             add_extra_element (e, "spaces_associated_command", 
current->parent);
@@ -141,7 +141,7 @@ handle_open_brace (ELEMENT *current, char **line_inout)
           if (command_data(command).data > 0)
             {
               ELEMENT *e;
-              e = new_element (ET_empty_spaces_before_argument);
+              e = new_element (ET_internal_spaces_before_argument);
               /* See comment in parser.c:merge_text */
               text_append (&e->text, "");
               add_to_element_contents (current, e);
@@ -166,7 +166,7 @@ handle_open_brace (ELEMENT *current, char **line_inout)
       if (current->parent->parent->type == ET_def_line)
         current->source_info = current_source_info;
 
-      e = new_element (ET_empty_spaces_before_argument);
+      e = new_element (ET_internal_spaces_before_argument);
       text_append (&e->text, ""); /* See comment in parser.c:merge_text */
       add_to_element_contents (current, e);
       debug ("BRACKETED in def/multitable");
@@ -193,7 +193,7 @@ handle_open_brace (ELEMENT *current, char **line_inout)
       line_error ("misplaced {");
       if (current->contents.number > 0
           && last_contents_child(current)->type
-               == ET_empty_spaces_before_argument)
+               == ET_internal_spaces_before_argument)
         {
           /* FIXME: Is this right? */
           remove_from_contents (current, 0);
@@ -716,7 +716,7 @@ inlinefmtifelse_done:
   new_arg = new_element (type);
   add_to_element_args (current, new_arg);
   current = new_arg;
-  e = new_element (ET_empty_spaces_before_argument);
+  e = new_element (ET_internal_spaces_before_argument);
   text_append (&e->text, ""); /* See comment in parser.c:merge_text */
   add_to_element_contents (current, e);
   add_extra_element (e, "spaces_associated_command", current);



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/tp/Texinfo/ParserNonXS.pm b/tp/Texinfo/ParserNonXS.pm
index d2bdf5cf80..1415dbf3a7 100644
--- a/tp/Texinfo/ParserNonXS.pm
+++ b/tp/Texinfo/ParserNonXS.pm
@@ -1834,7 +1834,7 @@ sub _close_current($$$;$$)
           and @{$current->{'contents'}}
           and $current->{'contents'}->[0]->{'type'}
           and $current->{'contents'}->[0]->{'type'}
-                eq 'empty_spaces_before_argument') {
+                eq 'internal_spaces_before_argument') {
         # remove spaces element from tree and update extra values
         _abort_empty_line($self, $current);
       }
@@ -1940,8 +1940,8 @@ sub _merge_text {
     if ($current->{'contents'} and @{$current->{'contents'}}
       and $current->{'contents'}->[-1]->{'type'}
       and ($current->{'contents'}->[-1]->{'type'} eq 'empty_line_after_command'
-         or $current->{'contents'}->[-1]->{'type'} eq 
'internal_empty_line_after_command'
-         or $current->{'contents'}->[-1]->{'type'} eq 
'empty_spaces_before_argument'
+         or $current->{'contents'}->[-1]->{'type'} eq 
'internal_spaces_after_command'
+         or $current->{'contents'}->[-1]->{'type'} eq 
'internal_spaces_before_argument'
          or $current->{'contents'}->[-1]->{'type'} eq 
'empty_spaces_after_close_brace')) {
       $no_merge_with_following_text = 1;
     }
@@ -2317,8 +2317,8 @@ sub _abort_empty_line {
        and $current->{'contents'}->[-1]->{'type'}
        and ($current->{'contents'}->[-1]->{'type'} eq 'empty_line'
            or $current->{'contents'}->[-1]->{'type'} eq 
'empty_line_after_command'
-           or $current->{'contents'}->[-1]->{'type'} eq 
'internal_empty_line_after_command'
-           or $current->{'contents'}->[-1]->{'type'} eq 
'empty_spaces_before_argument'
+           or $current->{'contents'}->[-1]->{'type'} eq 
'internal_spaces_after_command'
+           or $current->{'contents'}->[-1]->{'type'} eq 
'internal_spaces_before_argument'
            or $current->{'contents'}->[-1]->{'type'} eq 
'empty_spaces_after_close_brace')) {
 
     my $spaces_element = $current->{'contents'}->[-1];
@@ -2342,8 +2342,8 @@ sub _abort_empty_line {
       } else {
         delete $spaces_element->{'type'};
       }
-    } elsif ($spaces_element->{'type'} eq 'internal_empty_line_after_command'
-             or $spaces_element->{'type'} eq 'empty_spaces_before_argument') {
+    } elsif ($spaces_element->{'type'} eq 'internal_spaces_after_command'
+             or $spaces_element->{'type'} eq 
'internal_spaces_before_argument') {
       # Remove element from main tree. It will still be referenced in
       # the 'extra' hash as 'spaces_before_argument'.
       pop @{$current->{'contents'}};
@@ -3616,7 +3616,7 @@ sub _start_empty_line_after_command($$$) {
   if (defined($command)) {
     $current->{'contents'}->[-1]->{'extra'}->{'spaces_associated_command'}
       = $command;
-    $current->{'contents'}->[-1]->{'type'} = 
'internal_empty_line_after_command';
+    $current->{'contents'}->[-1]->{'type'} = 'internal_spaces_after_command';
   }
   return $line;
 }
@@ -4324,12 +4324,12 @@ sub _process_remaining_on_line($$$$)
     _abort_empty_line($self, $current);
     $line =~ s/^\*//;
     push @{$current->{'contents'}}, { 'parent' => $current,
-                                      'type' => 'menu_star',
+                                      'type' => 'internal_menu_star',
                                       'text' => '*' };
   # a space after a * at the beginning of a menu line
   } elsif ($current->{'contents'} and @{$current->{'contents'}}
            and $current->{'contents'}->[-1]->{'type'}
-           and $current->{'contents'}->[-1]->{'type'} eq 'menu_star') {
+           and $current->{'contents'}->[-1]->{'type'} eq 'internal_menu_star') 
{
     if ($line !~ /^\s+/) {
       print STDERR "ABORT MENU STAR ($line)\n" if ($self->{'DEBUG'});
       delete $current->{'contents'}->[-1]->{'type'};
@@ -5206,10 +5206,10 @@ sub _process_remaining_on_line($$$$)
           }
           $line =~ s/([^\S\f\n]*)//;
           $current->{'type'} = 'brace_command_context';
           # empty_spaces_before_argument is a transient internal type,
           # which should end up in extra spaces_before_argument.
           push @{$current->{'contents'}}, {
-            'type' => 'empty_spaces_before_argument',
+            'type' => 'internal_spaces_before_argument',
             'text' => $1,
             'parent' => $current,
             'extra' => {'spaces_associated_command' => $current->{'parent'}}
@@ -5221,10 +5221,10 @@ sub _process_remaining_on_line($$$$)
           if ($brace_commands{$command}
               and $brace_commands{$command} =~ /^\d$/
               and $brace_commands{$command} > 0) {
             # empty_spaces_before_argument is a transient internal type,
             # which should end up in extra spaces_before_argument.
             push @{$current->{'contents'}}, {
-                        'type' => 'empty_spaces_before_argument',
+                        'type' => 'internal_spaces_before_argument',
                         'text' => '',
                         'parent' => $current,
                         'extra' => {'spaces_associated_command' => $current}
@@ -5250,10 +5250,10 @@ sub _process_remaining_on_line($$$$)
         $current->{'source_info'} = $source_info
           if ($current->{'parent'}->{'parent'}->{'type'}
               and $current->{'parent'}->{'parent'}->{'type'} eq 'def_line');
         # empty_spaces_before_argument is a transient internal type,
         # which should end up in extra spaces_before_argument.
         push @{$current->{'contents'}},
-            {'type' => 'empty_spaces_before_argument',
+            {'type' => 'internal_spaces_before_argument',
              'text' => '',
              'parent' => $current,
              'extra' => {'spaces_associated_command' => $current}
@@ -5647,10 +5647,10 @@ sub _process_remaining_on_line($$$$)
       push @{$current->{'args'}},
            { 'type' => $type, 'parent' => $current, 'contents' => [] };
       $current = $current->{'args'}->[-1];
       # empty_spaces_before_argument is a transient internal type,
       # which should end up in extra spaces_before_argument.
       push @{$current->{'contents'}},
-             {'type' => 'empty_spaces_before_argument',
+             {'type' => 'internal_spaces_before_argument',
               'text' => '',
               'parent' => $current,
               'extra' => {'spaces_associated_command' => $current}
@@ -5758,7 +5758,7 @@ sub _parse_texi($$$)
           and $current->{'contents'}->[-1]
           and $current->{'contents'}->[-1]->{'type'}
           and $current->{'contents'}->[-1]->{'type'}
-               eq 'empty_spaces_before_argument') {
+               eq 'internal_spaces_before_argument') {
         # Empty spaces after brace or comma till the end of line.
         # Remove this element and update 'extra' values.
         _abort_empty_line($self, $current);
@@ -5206,10 +5206,10 @@ sub _process_remaining_on_line($$$$)
           $line =~ s/([^\S\f\n]*)//;
           $current->{'type'} = 'brace_command_context';
-          # empty_spaces_before_argument is a transient internal type,
+          # internal_spaces_before_argument is a transient internal type,
           # which should end up in extra spaces_before_argument.
           push @{$current->{'contents'}}, {
@@ -5221,10 +5221,10 @@ sub _process_remaining_on_line($$$$)
               and $brace_commands{$command} =~ /^\d$/
               and $brace_commands{$command} > 0) {
-            # empty_spaces_before_argument is a transient internal type,
+            # internal_spaces_before_argument is a transient internal type,
             # which should end up in extra spaces_before_argument.
             push @{$current->{'contents'}}, {
@@ -5250,10 +5250,10 @@ sub _process_remaining_on_line($$$$)
           if ($current->{'parent'}->{'parent'}->{'type'}
               and $current->{'parent'}->{'parent'}->{'type'} eq 'def_line');
-        # empty_spaces_before_argument is a transient internal type,
+        # internal_spaces_before_argument is a transient internal type,
         # which should end up in extra spaces_before_argument.
         push @{$current->{'contents'}},
@@ -5647,10 +5647,10 @@ sub _process_remaining_on_line($$$$)
            { 'type' => $type, 'parent' => $current, 'contents' => [] };
       $current = $current->{'args'}->[-1];
-      # empty_spaces_before_argument is a transient internal type,
+      # internal_spaces_before_argument is a transient internal type,
       # which should end up in extra spaces_before_argument.
       push @{$current->{'contents'}},
diff --git a/tp/Texinfo/XS/parsetexi/menus.c b/tp/Texinfo/XS/parsetexi/menus.c
index 976cad250c..394f2edf5b 100644
--- a/tp/Texinfo/XS/parsetexi/menus.c
+++ b/tp/Texinfo/XS/parsetexi/menus.c
@@ -111,16 +111,16 @@ handle_menu (ELEMENT **current_inout, char **line_inout)
       abort_empty_line (&current, 0);
       line++; /* Past the '*'. */
 
-      star = new_element (ET_menu_star);
+      star = new_element (ET_internal_menu_star);
       text_append (&star->text, "*");
       add_to_element_contents (current, star);
 
       /* The ET_menu_star element won't appear in the final tree. */
     }
   /* A space after a "*" at the beginning of a line. */
   else if (strchr (whitespace_chars, *line)
            && current->contents.number > 0
-           && last_contents_child(current)->type == ET_menu_star)
+           && last_contents_child(current)->type == ET_internal_menu_star)
     {
       ELEMENT *menu_entry, *leading_text, *entry_name;
       int leading_spaces;
@@ -172,7 +172,7 @@ handle_menu (ELEMENT **current_inout, char **line_inout)
     }
   /* A "*" followed by anything other than a space. */
   else if (current->contents.number > 0
-           && last_contents_child(current)->type == ET_menu_star)
+           && last_contents_child(current)->type == ET_internal_menu_star)
     {
       debug ("ABORT MENU STAR");
       last_contents_child(current)->type = ET_NONE;
@@ -111,16 +111,16 @@ handle_menu (ELEMENT **current_inout, char **line_inout)
       add_to_element_contents (current, star);
 
-      /* The ET_menu_star element won't appear in the final tree. */
+      /* The ET_internal_menu_star element won't appear in the final tree. */
     }
   /* A space after a "*" at the beginning of a line. */